# Python Package for DS-Student-Resources Companion Notebook

This package was built to help students receive a better learning experience and achieve greater level of success in the Data Science Program.
___




To Install
-----

**From the terminal:** 
    
    pip install DS-Students

**From Jupyter:** 
    
    !pip install DS_Students

To Import
-----

    From DS_Students import MultipleChoice

## Use Case
### Input
```

Q1 = MultipleChoice('Which of these fruits start with the letter A?',['Apple','Banana','Pear'],'Apple')
```
```
display(Q1)
```
### Output
----

![alt text](https://github.com/woz-u/DS-Student-Resources/blob/main/DS101-Basic-Statistics/Media/Bubble.png?raw=true)
